@@ -2,9 +2,10 @@ package Geo::Coder::Google::V2;
 
 use strict;
 use warnings;
-our $VERSION = '0.19_01';
+our $VERSION = '0.07';
 
 use Carp;
+use Encode;
 use JSON;
 use HTTP::Request;
 use LWP::UserAgent;
@@ -13,13 +14,16 @@ use URI;
 sub new {
     my($class, %param) = @_;
 
+    my $key = delete $param{apikey}
+        or Carp::croak("Usage: new(apikey => \$apikey)");
+
     my $ua       = delete $param{ua}       || LWP::UserAgent->new(agent => __PACKAGE__ . "/$VERSION");
     my $host     = delete $param{host}     || 'maps.google.com';
     my $language = delete $param{language};
     my $gl       = delete $param{gl};
     my $oe       = delete $param{oe}       || 'utf8';
 
-    bless { ua => $ua, host => $host, language => $language, gl => $gl, oe => $oe }, $class;
+    bless { key => $key, ua => $ua, host => $host, language => $language, gl => $gl, oe => $oe }, $class;
 }
 
 sub ua {
@@ -43,8 +47,12 @@ sub geocode {
     my $location = $param{location}
         or Carp::croak("Usage: geocode(location => \$location)");
 
+    if (Encode::is_utf8($location)) {
+        $location = Encode::encode_utf8($location);
+    }
+
     my $uri = URI->new("http://$self->{host}/maps/geo");
-    my %query_parameters = (q => $location, output => 'json');
+    my %query_parameters = (q => $location, output => 'json', key => $self->{key});
     $query_parameters{hl} = $self->{language} if defined $self->{language};
     $query_parameters{gl} = $self->{gl} if defined $self->{gl};
     $query_parameters{oe} = $self->{oe};
@@ -74,29 +82,27 @@ Geo::Coder::Google::V2 - Google Maps Geocoding API V2
 
   use Geo::Coder::Google;
 
-  my $geocoder = Geo::Coder::Google->new();
+  my $geocoder = Geo::Coder::Google->new(apikey => 'Your API Key');
   my $location = $geocoder->geocode( location => 'Hollywood and Highland, Los Angeles, CA' );
 
 =head1 DESCRIPTION
 
 Geo::Coder::Google::V2 provides a geocoding functionality using Google Maps API V2.
 
-B<Note: Google no longer supports the V2 API. There are no longer any V2 servers to
-connect to. Any attempt to use the V2 API will fail.>
-
 =head1 METHODS
 
 =over 4
 
 =item new
 
-  $geocoder = Geo::Coder::Google->new();
-  $geocoder = Geo::Coder::Google->new(host => 'maps.google.co.jp');
-  $geocoder = Geo::Coder::Google->new(language => 'ru');
-  $geocoder = Geo::Coder::Google->new(gl => 'ca');
-  $geocoder = Geo::Coder::Google->new(oe => 'latin1');
+  $geocoder = Geo::Coder::Google->new(apikey => 'Your API Key');
+  $geocoder = Geo::Coder::Google->new(apikey => 'Your API Key', host => 'maps.google.co.jp');
+  $geocoder = Geo::Coder::Google->new(apikey => 'Your API Key', language => 'ru');
+  $geocoder = Geo::Coder::Google->new(apikey => 'Your API Key', gl => 'ca');
+  $geocoder = Geo::Coder::Google->new(apikey => 'Your API Key', oe => 'latin1');
 
-Creates a new geocoding object.
+Creates a new geocoding object. You should pass a valid Google Maps
+API Key as C<apikey> parameter.
 
 When you'd like to query Japanese address, you might want to set
 I<host> parameter, which should point to I<maps.google.co.jp>. I think
